const { useState, useEffect } = React;
const {
  select,
  axisLeft,
  axisBotton,
  csv,
  arc,
  pie,
  scaleBand,
  scaleLinear,
  max,
  format,
} = d3;
const csvURL =
  "https://gist.githubusercontent.com/maanaskatta/adfe0e9e145072e396fbb53cb2124628/raw/b5c8fda144868c38bab45f8f19d0a7f20e19770c/AirPollution2017.csv";

const width = 800;

const height = 300;
const margin = { top: 60, right: 120, bottom: -40, left: 200 };

const BarChart = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    csv(csvURL).then((data) => {
      let res = data.map((el) => {
        return {
          country: el.Country,
          deaths: el.Deaths,
        };
      });
      setData(res);
    });
  }, []);

  const innerHeight = height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right;

  if (data) {
    const yScale = scaleBand()
      .domain(data.map((d) => d.country))
      .range([0, innerHeight]);

    const xScale = scaleLinear()
      .domain([0, max(data, (d) => d.deaths)])
      .range([0, innerWidth]);

    return (
      <div
        style={{
          border: "2px dashed violet",
          backgroundColor: "black",
          borderRadius: 30,
        }}
      >
        <svg width={width} height={height}>
          <g transform={`translate(${margin.left},${margin.top})`}>
            {xScale.ticks().map((tickValue) => (
              <g
                key={tickValue}
                transform={`translate(${xScale(tickValue)},0)`}
              >
                <line y2={innerHeight} stroke="violet" stroke-width="2" />
                <text
                  style={{ textAnchor: "middle", fill: "violet" }}
                  dy=".70em"
                  y={innerHeight + 3}
                >
                  {tickValue}
                </text>
              </g>
            ))}

            {yScale.domain().map((tickValue, index) => (
              <text
                key={tickValue}
                style={{
                  textAnchor: "end",
                  fill: index % 2 == 0 ? "skyblue" : "deepskyblue",
                }}
                x={-10}
                dy=".35em"
                y={yScale(tickValue) + yScale.bandwidth() / 2}
              >
                {tickValue}
              </text>
            ))}

            {data.map((d, index) => (
              <rect
                key={d.country}
                y={yScale(d.country)}
                width={xScale(d.deaths)}
                height={yScale.bandwidth()}
                style={{
                  fill: index % 2 == 0 ? "skyblue" : "deepskyblue",
                  stroke: "black",
                }}
                shape-rendering="geometricPrecision"
              />
            ))}
          </g>
        </svg>
      </div>
    );
  }
  return <pre>Loading...</pre>;
};

const rootElement = document.getElementById("root");
ReactDOM.render(<BarChart />, rootElement);
